#-*- perl -*-

package Unicode::LineBreak;

=encoding utf8

This file is automatically generated.  DON'T EDIT THIS FILE MANUALLY.

=cut

our $VERSION = '1.000.510';
use constant { UNICODE_VERSION => '5.1.0' };

1;
